@@ -1,6 +1,6 @@
 # appteka - helpers collection
 
-# Copyright (C) 2018-2020 Aleksandr Popov
+# Copyright (C) 2018-2021 Aleksandr Popov
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the Lesser GNU General Public License as published by
@@ -15,6 +15,6 @@
 # You should have received a copy of the Lesser GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Initial script."""
+"""Initialization."""
 
-__version__ = '0.11.0'
+__version__ = '0.13.0'
