@@ -1,6 +1,6 @@
 # appteka - helpers collection
 
-# Copyright (C) 2018-2020 Aleksandr Popov
+# Copyright (C) 2018-2021 Aleksandr Popov
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the Lesser GNU General Public License as published by
@@ -18,13 +18,14 @@
 """Waveform widgets."""
 
 import time
-from warnings import warn
-from PyQt5.QtCore import Qt
+
 import pyqtgraph as pg
+from pyqtgraph.Qt import QtCore
 
 
 class TimeStampAxisItem(pg.AxisItem):
     """Axis with times or dates as ticks."""
+
     def __init__(self, what_show='time', *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.enableAutoSIPrefix(enable=False)
@@ -44,6 +45,7 @@ class TimeStampAxisItem(pg.AxisItem):
 
 def get_time_stamp_axis_item(top=True):
     """Return custom axis item with time stamps."""
+
     res = {
         'bottom': TimeStampAxisItem(
             what_show='time',
@@ -60,6 +62,7 @@ def get_time_stamp_axis_item(top=True):
 
 class Waveform(pg.PlotWidget):
     """Customized PyQtGraph.PlotWidget."""
+
     def __init__(self, parent=None, xlabel=None, time_axis=True):
         if time_axis:
             axis_items = get_time_stamp_axis_item()
@@ -117,10 +120,10 @@ class Waveform(pg.PlotWidget):
         self.setLimits(xMin=t[0], xMax=t[-1])
 
     def keyPressEvent(self, ev):
-        if ev.key() == Qt.Key_Shift:
+        if ev.key() == QtCore.Qt.Key_Shift:
             self.setMouseEnabled(x=False, y=True)
 
-        if ev.key() == Qt.Key_Control:
+        if ev.key() == QtCore.Qt.Key_Control:
             self.setMouseEnabled(x=True, y=False)
 
         super().keyPressEvent(ev)
@@ -136,6 +139,7 @@ class Waveform(pg.PlotWidget):
 
 class MultiWaveform(pg.GraphicsLayoutWidget):
     """Customized PyQtGraph.GraphicsLayoutWidget."""
+
     def __init__(self, parent=None):
         """Initialization."""
         super().__init__(parent)
@@ -178,7 +182,7 @@ class MultiWaveform(pg.GraphicsLayoutWidget):
             )
         plot.enableAutoRange(True)
 
-    def add_plot(self, key, title=None, main=None, time_axes=False):
+    def add_plot(self, key, title=None, time_axes=False):
         """Add plot."""
         if time_axes:
             axes = get_time_stamp_axis_item()
@@ -194,9 +198,6 @@ class MultiWaveform(pg.GraphicsLayoutWidget):
         self.curves[key] = self.plots[key].plot()
         self.curves[key].setPen(self.state['plot_color'])
 
-        if main is not None:
-            warn("MultiWaveform.add_plot(): deprecated main arg was ignored")
-
     def set_title(self, plot_key, value):
         """Changes title of the given plot."""
         self.plots[plot_key].setTitle(value, justify='left')
@@ -238,13 +239,6 @@ class MultiWaveform(pg.GraphicsLayoutWidget):
                 plot.setClipToView(False)
                 plot.setMouseEnabled(x=True)
 
-    def set_plot_color(self, color):
-        """Set color for all plots."""
-        message = "MultiWaveform.set_plot_color() is deprecated. "
-        message += "Use MultiWaveform.set_plots_color()."
-        warn(message)
-        self.set_plots_color(color)
-
     def set_plots_color(self, color):
         """Set color for all plots."""
         for curve in self.curves.values():
@@ -259,11 +253,11 @@ class MultiWaveform(pg.GraphicsLayoutWidget):
             self.plots[key].setXLink(self.plots[self._main] if value else None)
 
     def keyPressEvent(self, ev):
-        if ev.key() == Qt.Key_Shift:
+        if ev.key() == QtCore.Qt.Key_Shift:
             for plot in self.plots.values():
                 plot.setMouseEnabled(x=False, y=True)
 
-        if ev.key() == Qt.Key_Control:
+        if ev.key() == QtCore.Qt.Key_Control:
             for plot in self.plots.values():
                 plot.setMouseEnabled(x=True, y=False)
 
