@@ -44,11 +44,18 @@ class TestMultiWavefrom(unittest.TestCase):
         app = testing.TestApp(self)
 
         w = MultiWaveform()
-
         w.add_plot('a', title='Title one')
         w.update_data('a', [0, 1, 2, 3], [1, 2, 1, 2])
         w.set_title(plot_key='a', value='Frequency: 50.123')
 
-        app(w, [
-            "Title is 'Frequency: 50.123'",
-        ])
+        app(w, ["Title is 'Frequency: 50.123'"])
+
+    def test_color(self):
+        app = testing.TestApp(self)
+
+        w = MultiWaveform()
+        w.add_plot('a')
+        w.set_plots_color((255, 0, 0))
+        w.update_data('a', [0, 1, 2, 3], [1, 2, 1, 2])
+
+        app(w, ["Red plot"])
